@@ -6,6 +6,7 @@ import hashlib
 import hmac
 
 try:
+    import urllib.parse
     quote_plus = urllib.parse.quote_plus
 except AttributeError:
     quote_plus = urllib.quote_plus
@@ -15,7 +16,15 @@ from intelab_python_sdk.utils import do_request
 
 
 class DingTalkMessage(object):
-    """钉钉机器人消息推送
+    """ 钉钉机器人消息推送
+
+    Usage::
+        >>> from intelab_python_sdk.dingtalk import DingTalkMessage
+        >>> dingtalk = DingTalkMessage(webhook, secret)
+        >>> dingtalk.send_text('这是文本信息', mobiles=['15131601294'], at_all=False)  # mobiles是at群中的人(手机号),at_all为True是at全体
+        >>> dingtalk.send_link('这是标题', '这是内容', 'https://www.baidu.com')
+        >>> dingtalk.send_markdown('这是标题', '# 这是内容 \n> 这是引用\n [百度](https://baidu.com)')
+
     """
 
     headers = {"Content-Type": "application/json;charset=utf-8"}
@@ -72,6 +81,33 @@ class DingTalkMessage(object):
         log.debug('link类型：%s' % msg_dict)
         return self._send(msg_dict)
 
+    def send_markdown(self, title, text, mobiles=None, at_all=False):
+        """ markdown
+
+        :param title: 消息标题
+        :param text: 消息内容。支持简单的md语法。
+        :param: mobiles:
+        :param at_all:
+        :return:
+        """
+        if mobiles is None:
+            mobiles = []
+
+        msg_dict = {
+            "msgtype": "markdown",
+            "markdown": {
+                "title": title,
+                "text": text,
+            },
+            "at": {
+                "atMobiles": mobiles,
+                "isAtAll": at_all
+            }
+        }
+        return self._send(msg_dict)
+
+
+
     def _update_webhook(self):
         """
         钉钉群自定义机器人安全设置加签时，签名中的时间戳与请求时不能超过一个小时，
@@ -108,7 +144,9 @@ class DingTalkMessage(object):
                              headers=self.headers)
             if 'errcode' in res and res['errcode'] == 0:
                 log.info('dingtalk message sent is successful.')
+                return True
             else:
                 raise ValueError(res)
         except Exception as e:
             log.error("dingtalk message sent is unsuccessful!!!\n %s", e)
+        return False
